import configparser

config = configparser.ConfigParser()
if not config.read(
        filenames="./config.ini",
        encoding="utf-8"):
    config["values.common"] = {"reserved": "reserved"}
    config["values.prefix"] = {"kilo": "k"}
    config["values.enum"] = {
        "time_year": "a",
        "time_month": "mo",
        "time_week": "wk",
        "time_day": "d",
        "time_hour": "h",
        "time_minute": "min",
        "time_second": "s",
        "phase_angle_degree": "°",
        "temperature": "°c",
        "local_currency": "currency",
        "length_metre": "m",
        "speed_metre_per_second": "m / s",
        "volume_value_cubic_metre": "m³",
        "corrected_volume_cubic_metre": "m³ *",
        "volume_flux_cubic_metre_per_hour": "m³ / h",
        "corrected_volume_flux_cubic_metre_per_hour": "m³ / h *",
        "volume_flux_cubic_metre_per_day": "m³ / d",
        "corrected_volume_flux_cubic_metre_per_day": "m³ / d",
        "volume_litre": "l",
        "mass_kilogram": "kg",
        "force_newton": "n",
        "energy_newton_meter": "nm",
        "pressure_pascal": "pa",
        "pressure_bar": "bar",
        "energy_joule": "j",
        "thermal_power_rate_of_change_joule_per_hour": "j / h",
        "active_power_watt": "w",
        "apparent_power_volt_ampere": "va",
        "reactive_power_var": "var",
        "active_energy_value_watt_hour": "wh",
        "apparent_energy_value_volt_ampere_hour": "vah",
        "reactive_energy_value_var_hour": "varh",
        "current_ampere": "a",
        "electrical_charge_coulomb": "c",
        "voltage_volt": "v",
        "electric_field_strength_volt_per_metre": "v / m",
        "capacitance_farad": "f",
        "resistance_ohm": "ω",
        "resistivity": "ωm² / m",
        "magnetic_flux_weber": "wb",
        "magnetic_flux_density_tesla": "t",
        "magnetic_field_strength_ampere_per_metre": "a / m",
        "inductance_henry": "h",
        "frequency_hertz": "hz",
        "rw_active_energy_value": "1 / (wh)",
        "rb_reactive_energy_value": "1 / (varh)",
        "rs_apparent_energy_value": "1 / (vah)",
        "volt_squared_hour_volt_squared_hour_meter": "v²h",
        "ampere_squared_hour": "a²h",
        "mass_flux_kilogram_per_second": "kg / s",
        "conductance_siemens": "s, mho",
        "temperature_kelvin": "k",
        "ru2h_volt_squared_hour_meter": "1 / (v²h)",
        "ri2h_ampere_squared_hour_meter": "1 / (a²h)",
        "rv_meter": "1 / m³",
        "percentage": "%%",
        "ampere_hours": "ah",
        "energy_per_volume": "wh / m³",
        "calorific_value_wobbe": "j / m³",
        "molar_fraction_of_gas_composition_mole_percent": "mol %%",
        "mass_density_quantity_of_material": "g / m³",
        "dynamic_viscosity_pascal_second": "pa s",
        "specific_energy_joule_kilogram": "j / kg",
        "pressure_gram_per_square_centimeter": "g / cm²",
        "pressure_atmosphere": "atm",
        "signal_strength_milliwatt": "dbm",
        "signal_strength_microvolt": "dbµv",
        "logarithmic_unit": "db",
        "length_inch": "in",
        "length_foot": "ft",
        "mass_pound": "lb",
        "temperature_fahrenheit": "°f",
        "temperature_rankine": "°r",
        "area_square_inch": "sq. in",
        "area_square_foot": "sq ft",
        "area_acre": "ac",
        "volume_cubic_inch": "cu in",
        "volume_cubic_foot": "cu ft",
        "volume_acre_foot": "ac ft",
        "volume_gallon_imperial": "gal(imp)",
        "volume_gallon_us": "gal(us)",
        "force_pound_force": "lbf",
        "pressure_pound_force_per_square_inch": "psi",
        "density_pound_per_cubic_foot": "lb / cu ft",
        "dynamic_viscosity": "lb / (ft.s)",
        "kinematic_viscosity_square_foot_per_second": "sq ft / s",
        "energy_british_thermal_unit": "btu",
        "energy_therm_eu": "thm(ec)",
        "energy_therm_us": "thm(us)",
        "calorific_value_of_mass_lenthalpy": "btu / lb",
        "calorific_value_of_volume_wobbe": "btu / cu ft",
        "volume_meter_cubic_feet_rv": "cu ft rv",
        "speed_foot_per_second": "ft / s",
        "volume_flux_cubic_foot_per_second": "cu ft/s",
        "volume_flux_cubic_foot_per_min": "cu ft/min",
        "volume_flux_cubic_foot_per_hour": "cu ft/h",
        "volume_flux_cubic_foot_per_day": "cu ft/d",
        "volume_flux_acre_foot_per_second": "ac ft/s",
        "volume_flux_acre_foot_per_min": "ac ft/min",
        "volume_flux_acre_foot_per_hour": "ac ft/h",
        "volume_flux_acre_foot_per_day": "ac ft/d",
        "volume_imperial_gallon_meter_rv": "gal(imp) rv",
        "volume_flux_imperial_gallon_per_second": "gal(imp) / s",
        "volume_flux_imperial_gallon_per_min": "gal(imp) / min",
        "volume_flux_imperial_gallon_per_hour": "gal(imp) / h",
        "volume_flux_imperial_gallon_per_day": "gal(imp) / d",
        "volume_us_gallon_rv": "gal(us) rv",
        "volume_flux_us_gallon_per_second": "gal(us) / s",
        "volume_flux_us_gallon_per_min": "gal(us) / min",
        "volume_flux_us_gallon_per_hour": "gal(us) / h",
        "volume_flux_us_gallon_per_day": "gal(us) / d",
        "energy_flow_british_thermal_unit_per_second": "btu / s",
        "energy_flow_british_thermal_unit_per_minute": "btu / min",
        "energy_flow_british_thermal_unit_per_hour": "btu / h",
        "energy_flow_british_thermal_unit_per_day": "btu / d",
        "extended_table_of_units": "extended",
        "other_unit": "other",
        "no_unit_unitless_count": "count}"}
