OPTICAL_PORT = "Optical port"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "not defined"
INTERNAL_CRYSTAL = "internal crystal"
MAINS_FREQUENCY_50_HZ = "mains frequency 50 Hz"
MAINS_FREQUENCY_60_HZ = "mains frequency 60 Hz"
GPS_GLOBAL_POSITIONING_SYSTEM = "GPS (global positioning system)"
RADIO_CONTROLLED = "radio controlled"
CONTROL_MODE_0 = "None. The disconnect control object is always in <connected> state"
CONTROL_MODE_1 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e)"
CONTROL_MODE_2 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(a), manual(e)"
CONTROL_MODE_3 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(d), manual(e)"
CONTROL_MODE_4 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(a), manual(e)"
CONTROL_MODE_5 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e), local(h)"
CONTROL_MODE_6 = "Disconnection: remote(b, c), local(g) Reconnection: remote(d), manual(e), local(h)"
RU_CONTROL_MODE_129 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_130 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(a), manual(e)"
RU_CONTROL_MODE_131 = "Disconnection: remote(b, c), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_132 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a)"
RU_CONTROL_MODE_133 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a), local(k)"
RU_CONTROL_MODE_134 = "Disconnection: remote(b, c), local(m, s) Reconnection: remote(d), manual(e), local(p)"
DISCONNECTED = "Disconnected"
CONNECTED = "Connected"
READY_FOR_RECONNECTION = "Ready for reconnection"
NOT_REGISTERED = "not registered"
REGISTERED_HOME_NETWORK = "registered, home network"
NOT_REGISTERED_BUT_MT = "not registered, but MT is currently searching a new operator to register to"
REGISTRATION_DENIED = "registration denied"
UNKNOWN = "unknown"
REGISTERED_ROAMING = "registered, roaming"
INACTIVE = "inactive"
INCOMING_CALL = "incoming call"
ACTIVE = "active"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 baud"
BAUD_600 = "600 baud"
BAUD_1200 = "1200 baud"
BAUD_2400 = "2400 baud"
BAUD_4800 = "4800 baud"
BAUD_9600 = "9600 baud"
BAUD_19200 = "19200 baud"
BAUD_38400 = "38400 baud"
BAUD_57600 = "57600 baud"
BAUD_115200 = "115200 baud"
IMAGE_TRANSFER_NOT_INITIATED = "Image transfer not initiated"
IMAGE_TRANSFER_INITIATED = "Image transfer initiated"
IMAGE_VERIFICATION_INITIATED = "Image verification initiated"
IMAGE_VERIFICATION_SUCCESSFUL = "Image verification successful"
IMAGE_VERIFICATION_FAILED = "Image verification failed"
IMAGE_ACTIVATION_INITIATED = "Image activation initiated"
IMAGE_ACTIVATION_SUCCESSFUL = "Image activation successful"
IMAGE_ACTIVATION_FAILED = "Image activation failed"
FIFO = "fifo (first in first out)"
LIFO = "lifo (last in first out)"
LARGEST = "largest"
SMALLEST = "smallest"
NEAREST_TO_ZERO = "nearest to zero"
FAREST_FROM_ZERO = "farest from zero"
WRITE_ATTRIBUTE = "write attribute"
EXECUTE_SPECIFIC_METHOD = "execute specific method"
SCHEDULE_TYPE_1 = "size of execution time = 1; wildcard in date allowed"
SCHEDULE_TYPE_2 = "size of execution time = n; all time values are the same, wildcard in date not allowed"
SCHEDULE_TYPE_3 = "size of execution time = n; all time values are the same, wildcard in date are allowed"
SCHEDULE_TYPE_4 = "size of execution time = n; time values may be different, wildcard in date not allowed"
SCHEDULE_TYPE_5 = "size of execution time = n; time values may be different, wildcard in date are allowed"
NO_ACCESS = "no access"
READ_ONLY = "read only"
WRITE_ONLY = "write only"
READ_AND_WRITE = "read and write"
NON_ASSOCIATED = "non associated"
ASSOCIATION_PENDING = "association pending"
ASSOCIATED = "associated"
NO_STATION = "no station"
CLIENT_MANAGEMENT_PROCESS = "Client Management Process"
PUBLIC_CLIENT = "Public client"
METER_READER = "Meter Reader"
UTILITY_SETTING = "Utility Settings"
PUSH = "Push"
FIRMWARE_UPDATE = "Firmware Update"
IHD = "IHD"
NONE = "NONE"
LOW = "LOW"
HIGH = "HIGH"
HIGH_MD5 = "HIGH MD5"
HIGH_SHA1 = "HIGH SHA1"
HIGH_GMAC = "HIGH GMAC"
HIGH_SHA256 = "HIGH SHA256"
HIGH_ECDSA = "HIGH ECDSA"
ACCESS = "access"
AUTHENTICATED_ACCESS = "authenticated_access"
NOTHING = "nothing"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "all messages to be authentication"
ALL_MESSAGES_TO_BE_ENCRYPTED = "all messages to be encrypted"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "all messages to be authentication and encrypted"
RESERVED = "reserved"
AUTHENTICATION_REQUEST = "authentication request"
ENCRYPTION = "encryption"
AUTHENTICATION_AND_ENCRYPTION = "authentication and encryption"
DIGITAL_SIGNATURE = "digital signature"
ENCRYPTED_REQUEST = "encrypted request"
DIGITALLY_SIGNED_REQUEST = "digitally signed request"
AUTHENTICATION_RESPONSE = "authentication response"
ENCRYPTED_RESPONSE = "encrypted response"
DIGITALLY_SIGNED_RESPONSE = "digitally signed response"
UNUSED = "unused, shall be set 0"
AUTHENTICATION = "authentication"
AUTHENTICATION_READ_ONLY = "authenticated_read_only"
AUTHENTICATION_WRITE_ONLY = "authenticated_write_only"
AUTHENTICATION_READ_AND_WRITE = "authenticated_read_and_write"
GUEK = "global unicast encryption key"
GBEK = "global broadcast encryption key"
GAK = "authentication key"
KEK = "master key"
AES_GCM_128 = "AES-GCM-128 for authenticated encryption and AES-128 for key wrapping"
AES_GCM_128_ECDSA_P_256 = "AES-GCM-128 authenticated encryption, ECDSA P-256 digital signature, ECDH P-256 key agreement, SHA-256 hash, V.44 compression and AES-128 key wrap"
AES_GCM_256_ECDSA_P_384 = "AES-GCM-256 authenticated encryption, ECDSA P-384 digital signature, ECDH P-384 key agreement, SHA-384 hash, V.44 compression and AES-256 key wrap"
SERVER = "server"
CLIENT_OR_THIRD_PARTY = "client or third party"
CERTIFICATION_AUTHORITY = "certification authority"
OTHER = "other"
KEY_AGREEMENT = "key agreement"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = "digital signature key pair"
KEY_AGREEMENT_KEY_PAIR = "key agreement key pair"
TLS_KEY_PAIR = "tls key pair"
CERTIFICATE_IDENTIFICATION_ENTITY = "certificate identification entity"
CERTIFICATE_IDENTIFICATION_SERIAL = "certificate identification serial"
RESTRICTION_BY_DATE = "restriction by date"
RESTRICTION_BY_ENTRY = "restriction by entry"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "reserved for FTP"
SMTP_RESERVED = "reserved for SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "reserved for ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Manufacturer specific"
A_XDR = "A-XDR encoded xDLMS APDU"
XML = "XML encoded xDLMS APDU"
UNCONFIRMED_FAILURE = "unconfirmed, retry on supporting protocol layer failure"
UNCONFIRMED_MISSING = "unconfirmed, retry on missing supporting protocol layer confirmation"
CONFIRMED = "confirmed, retry on missing confirmation"
MASTER_KEY = "master key"
GLOB_UNI_ENCR_KEY = "global unicast encryption key"
GLOB_BROAD_ENCR_KEY = "global broadcast encryption key"
IDENTIFIED_KEY = "identified key"
WRAPPED_KEY = "wrapped key"
AGREED_KEY = "agreed key"

# for GSM_diagnostic.cell_info
OR_LESS = "or less"
OR_GREATER = "or greater"
NOT_KNOWN_OR_NOT_DETECTABLE = "not known or not detectable"
