OPTICAL_PORT = "Оптический порт"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "не определен"
INTERNAL_CRYSTAL = "внутренний кварцевый генератор"
MAINS_FREQUENCY_50_HZ = "от сети 50 Гц"
MAINS_FREQUENCY_60_HZ = "от сети 60 Гц"
GPS_GLOBAL_POSITIONING_SYSTEM = "от системы GPS (GLONASS)"
RADIO_CONTROLLED = "от радиосигналов точного времени"
CONTROL_MODE_0 = "Отсутствует. Объект управления разъединением всегда находится в состоянии «подключено»"
CONTROL_MODE_1 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_2 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_3 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_4 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_5 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
CONTROL_MODE_6 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
RU_CONTROL_MODE_129 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_130 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(A), ручной(E)"
RU_CONTROL_MODE_131 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_132 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A)"
RU_CONTROL_MODE_133 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A), локальный(K)"
RU_CONTROL_MODE_134 = "Отключение: удаленные(B, C), локальный(M, S) Переподключение: удаленный(D), ручной(E), локальный(P)"
DISCONNECTED = "отключено"
CONNECTED = "включено"
READY_FOR_RECONNECTION = "Готово к переподключению"
NOT_REGISTERED = "не зарегистрирован"
REGISTERED_HOME_NETWORK = "зарегистрирован, домашняя сеть"
NOT_REGISTERED_BUT_MT = "не зарегистрирован, но MT в настоящее время ищет нового оператора для регистрации в"
REGISTRATION_DENIED = "регистрация отвергнута"
UNKNOWN = "неизвестно"
REGISTERED_ROAMING = "зарегистрирован, роуминг"
INACTIVE = "не aктивно"
INCOMING_CALL = "входящий звонок"
ACTIVE = "активно"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 бод"
BAUD_600 = "600 бод"
BAUD_1200 = "1200 бод"
BAUD_2400 = "2400 бод"
BAUD_4800 = "4800 бод"
BAUD_9600 = "9600 бод"
BAUD_19200 = "19200 бод"
BAUD_38400 = "38400 бод"
BAUD_57600 = "57600 бод"
BAUD_115200 = "115200 бод"
IMAGE_TRANSFER_NOT_INITIATED = "Передача данных не инициированна"
IMAGE_TRANSFER_INITIATED = "Передача данных инициированна"
IMAGE_VERIFICATION_INITIATED = "Проверка данных инициированна"
IMAGE_VERIFICATION_SUCCESSFUL = "Проверка данных пройдена"
IMAGE_VERIFICATION_FAILED = "Проверка данных неудачна"
IMAGE_ACTIVATION_INITIATED = "Активация данных инициированна"
IMAGE_ACTIVATION_SUCCESSFUL = "Активация данных пройдена"
IMAGE_ACTIVATION_FAILED = "Активация данных неудачна"
FIFO = "FIFO(первый пришел первый ушел)"
LIFO = "LIFO(последний пришел первый ушел)"
LARGEST = "наибольший"
SMALLEST = "наименьший"
NEAREST_TO_ZERO = "ближайший к нулю"
FAREST_FROM_ZERO = "дальний от нуля"
WRITE_ATTRIBUTE = "запись в атрибут"
EXECUTE_SPECIFIC_METHOD = "выполнить конкретный метод"
SCHEDULE_TYPE_1 = "Размер времени выполнения = 1; Подстановочный знак в дате разрешен"
SCHEDULE_TYPE_2 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак на дате не допускается"
SCHEDULE_TYPE_3 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак в дате разрешены"
SCHEDULE_TYPE_4 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочный знак даты не допускается"
SCHEDULE_TYPE_5 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочные знаки в дате разрешены"
NO_ACCESS = "нет доступа"
READ_ONLY = "только чтение"
WRITE_ONLY = "только запись"
READ_AND_WRITE = "чтение и запись"
NON_ASSOCIATED = "нет соединения"
ASSOCIATION_PENDING = "ожидание соединения"
ASSOCIATED = "соединение установлено"
NO_STATION = "Отсутствует"
CLIENT_MANAGEMENT_PROCESS = "Процесс управления клиентами"
PUBLIC_CLIENT = "Публичный клиент"
METER_READER = "Считыватель показаний"
UTILITY_SETTING = "Конфигуратор"
PUSH = "Инициативный"
FIRMWARE_UPDATE = "Обновление ПО"
IHD = "Домашний дисплей"
NONE = "Низший, без секретности"
LOW = "Низкий, без шифрования с паролем"
HIGH = "Высокий"
HIGH_MD5 = "Высокий, MD5"
HIGH_SHA1 = "Высокий, SHA1"
HIGH_GMAC = "Высокий, GMAC"
HIGH_SHA256 = "Высокий, SHA256"
HIGH_ECDSA = "Высокий, ECDSAL"
ACCESS = "доступно"
AUTHENTICATED_ACCESS = "доступ с проверкой подлинности"
NOTHING = "ничего не делать"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "Все сообщения должны быть аутентифицированы"
ALL_MESSAGES_TO_BE_ENCRYPTED = "Все сообщения должны быть зашифрованы"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "Все сообщения должны быть аутентифицированы и зашифрованы"
RESERVED = "зарезервировано"
AUTHENTICATION = "аутентификация"
AUTHENTICATION_REQUEST = "запрос с аутентификацией"
ENCRYPTION = "Шифрование"
AUTHENTICATION_AND_ENCRYPTION = "Аутентификация и шифрование"
DIGITAL_SIGNATURE = "Цифровая подпись"
ENCRYPTED_REQUEST = "зашифрованный запрос"
DIGITALLY_SIGNED_REQUEST = "запрос с цифровой подписью"
AUTHENTICATION_RESPONSE = "ответ с аутентификацией"
ENCRYPTED_RESPONSE = "зашифрованный ответ"
DIGITALLY_SIGNED_RESPONSE = "ответ с цифровой подписью"
UNUSED = "не используется, всегда 0"
AUTHENTICATION_READ_ONLY = "только чтение с проверкой подлинности"
AUTHENTICATION_WRITE_ONLY = "только запись с проверкой подлинности"
AUTHENTICATION_READ_AND_WRITE = "чтение и запись с проверкой подлинности"
GUEK = "Глобальный одноадресный ключ шифрования"
GBEK = "Глобальный широковещательный ключ шифрования"
GAK = "Ключ аутентификации"
KEK = "Мастер ключ"
AES_GCM_128 = "AES-GSM-128 аутентификация, шифрование и упаковка ключей"
AES_GCM_128_ECDSA_P_256 = "AES-GSM-128 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
AES_GCM_256_ECDSA_P_384 = "AES-GSM-256 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
SERVER = "Сервер"
CLIENT_OR_THIRD_PARTY = "Клиент"
CERTIFICATION_AUTHORITY = "Администратор"
OTHER = "Прочее"
KEY_AGREEMENT = "Соглосование ключей"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = F"{DIGITAL_SIGNATURE} пары ключей"
KEY_AGREEMENT_KEY_PAIR = "Соглосование пары ключей"
TLS_KEY_PAIR = "TLS пары ключей"
CERTIFICATE_IDENTIFICATION_ENTITY = "Идентификация сертификата по объекту"
CERTIFICATE_IDENTIFICATION_SERIAL = "Идентификация сертификата по серийному номеру"
RESTRICTION_BY_DATE = "Ограничение по дате"
RESTRICTION_BY_ENTRY = "Ограничение по входу"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "зарезервированно для FTP"
SMTP_RESERVED = "зарезервированно для SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "зарезервированно для ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Спецификация производителя"
A_XDR = "A-XDR кодировка xDLMS APDU"
XML = "XML кодировка xDLMS APDU"
UNCONFIRMED_FAILURE = "Неподтвержденная, повторение при поддержке сбоя на уровне протокола"
UNCONFIRMED_MISSING = "Неподтверждено, повторение пропущенного подтверждения протокола"
CONFIRMED = "подтверждено, повторите пропущенное подтверждение"
MASTER_KEY = "мастер ключ"
GLOB_UNI_ENCR_KEY = "Глобальный ключ шифрования одноадресный"
GLOB_BROAD_ENCR_KEY = "Глобальный ключ шифрования широковещательный"
IDENTIFIED_KEY = "Идентификационный ключ"
WRAPPED_KEY = "Обернутый ключ"
AGREED_KEY = "Согласованный ключ"

# for GSM_diagnostic.cell_info
OR_LESS = "или менее"
OR_GREATER = "или более"
NOT_KNOWN_OR_NOT_DETECTABLE = "не известно или не опознано"
